.. highlight:: rst

.. _Tutorial:

Tutorials
=========

Below is a collection of notebooks illustrating some typical climlab use cases.
These documents are built from Jupyter notebooks,
mostly based on class material developed by Brian Rose at the University at Albany.

For a more comprehensive set of climlab usage examples embedded within lecture notes on climate science,
see Brian's online textbook `The Climate Laboratory <https://brian-rose.github.io/ClimateLaboratoryBook/>`_.

If you want to run the code yourself, these notes are all available as Jupyter *.ipynb files
in the ``docs/source/courseware`` directory of the `climlab source <https://github.com/climlab/climlab>`_.

.. toctree::
   :titlesonly:

   courseware/Preconfigured_EBM
   courseware/Boltzmann_EBM
   courseware/Budyko_Transport_EBM
   courseware/Snowball_Earth_in_the_EBM
   courseware/Insolation
   courseware/Seasonal_cycle_and_heat_capacity
   courseware/Soundings_from_Observations_and_RCE_Models
   courseware/The_spectral_column_model
   courseware/Spectral_OLR_with_RRTMG
   courseware/Latitude-dependent_grey_radiation
   courseware/RCE_with_CAM3_radiation
   courseware/PolarAmplification
   courseware/Reset-time
